@@ -4,7 +4,7 @@
   Foundation.libs['magellan-expedition'] = {
     name : 'magellan-expedition',
 
-    version : '5.1.0',
+    version : '5.1.1',
 
     settings : {
       active_class: 'active',
@@ -29,9 +29,9 @@
 
       S(self.scope)
         .off('.magellan')
-        .on('click.fndtn.magellan', '[data-magellan-arrival] a[href^="#"]', function (e) {
+        .on('click.fndtn.magellan', '[' + self.add_namespace('data-magellan-arrival') + '] a[href^="#"]', function (e) {
             e.preventDefault();
-            var expedition = $(this).closest('[data-magellan-expedition]'),
+            var expedition = $(this).closest('[' + self.attr_name() + ']'),
                 settings = expedition.data('magellan-expedition-init');
 
             var hash = this.hash.split('#').join(''),
@@ -86,16 +86,16 @@
         if (window_top_offset >= top_offset) {
           // Placeholder allows height calculations to be consistent even when
           // appearing to switch between fixed/non-fixed placement
-          var placeholder = expedition.prev('[data-magellan-expedition-clone]');
+          var placeholder = expedition.prev('[' + self.add_namespace('data-magellan-expedition-clone') + ']');
           if (placeholder.length === 0) {
             placeholder = expedition.clone();
-            placeholder.removeAttr('data-magellan-expedition');
-            placeholder.attr('data-magellan-expedition-clone','');
+            placeholder.removeAttr(self.attr_name());
+            placeholder.attr(self.add_namespace('data-magellan-expedition-clone'),'');
             expedition.before(placeholder);
           }
           expedition.css({position:'fixed', top: 0});
         } else {
-          expedition.prev('[data-magellan-expedition-clone]').remove();
+          expedition.prev('[' + self.add_namespace('data-magellan-expedition-clone') + ']').remove();
           expedition.attr('style','');
         }
       });
@@ -165,7 +165,7 @@
     reflow : function () {
       var self = this;
       // remove placeholder expeditions used for height calculation purposes
-      $('[data-magellan-expedition-clone]', self.scope).remove();
+      $('[' + self.add_namespace('data-magellan-expedition-clone') + ']', self.scope).remove();
     }
   };
 }(jQuery, this, this.document));
\ No newline at end of file
